@@ -477,6 +477,47 @@ class PdbxEntryInfoIo(PdbxStyleIoUtil):
                 logger.exception("Failing with %s" % str(e))
         return False
 
+    def __getEmDepuiDetails(self):
+        """
+            Capture separate map depui information -
+
+            _em_depui.entry_id
+            _em_depui.depositor_hold_instructions
+            _em_depui.macromolecule_description
+            _em_depui.obsolete_instructions
+            _em_depui.same_authors_as_pdb
+            _em_depui.same_title_as_pdb
+
+            kys = ['entry_id',
+               'depositor_hold_instructions',
+               'macromolecule_description',
+               'obsolete_instructions',
+               'same_authors_as_pdb'
+               'same_title_as_pdb']
+
+        Return: dictionary of key value pairs -- where keys have "em_depui_" prefix -
+
+        """
+        kys = self.__stObj.getAttributeNameList('em_depui')
+        oD = {}
+        for ky in kys:
+            emKy = "em_depui_" + ky
+            oD[emKy] = ''
+        try:
+            cObj = self.getCurrentContainer()
+            catObj = cObj.getObj('em_depui')
+            if catObj is not None:
+                for ky in kys:
+                    emKy = "em_depui_" + ky
+                    oD[emKy] = catObj.getValueOrDefault(attributeName=ky, rowIndex=0, defaultValue='')
+        except Exception as e:
+            if (self.__verbose):
+                logger.info("+PdbxEntryInfoIo.getEmDepuiDetails() failed for file %s\n" % self.__filePath)
+            if (self.__debug):
+                logger.exception("Failing with %s" % str(e))
+
+        return oD
+
     def __getStatusDetails(self):
         """ Return selected status items from the pdbx_database_status category
 
@@ -627,6 +668,8 @@ class PdbxEntryInfoIo(PdbxStyleIoUtil):
             return self.__getInfoHistory()
         elif contextType == 'em_admin':
             return self.__getEmStatusDetails()
+        elif contextType == 'em_depui':
+            return self.__getEmDepuiDetails()
         else:
             return self.__getInfoGeneral()
 
