@@ -52,7 +52,7 @@ except:
 
 
 def tarinfoReset(tarinfo):
-    tarinfo.mode = 0o444
+    tarinfo.mode = 0o644
     tarinfo.uname = tarinfo.gname = 'nobody'
     return tarinfo
 
@@ -169,10 +169,10 @@ class PdbxStyleIoUtil(object):
         """
         try:
             # if 'logtag' in inspect.getargspec(self.__ioObj.readFile).args:
-            if logtag and len(logtag) > 0:
-                self.__currentContainerList.extend(self.__ioObj.readFile(filePath, logtag=logtag))
-            else:
-                self.__currentContainerList.extend(self.__ioObj.readFile(filePath))
+            #if logtag and len(logtag) > 0:
+            #    self.__currentContainerList.extend(self.__ioObj.readFile(filePath, logtag=logtag))
+            #else:
+            self.__currentContainerList.extend(self.__ioObj.readFile(filePath))
             self.__makeContainerIndex()
             for container in self.__currentContainerList:
                 self.__updateContainer(container)
@@ -422,7 +422,7 @@ class PdbxStyleIoUtil(object):
             return False
 
     #
-    def writeFile(self, filePath, applyConstraints=False, tmpPath="./tmpfiles"):
+    def writeFile(self, filePath, applyConstraints=False, tmpPath="./tmpfiles", doubleQuotingFlag=False):
         """  Write the current container list to the specified outputfile.
         """
         self.__outputFilePath = filePath
@@ -430,17 +430,17 @@ class PdbxStyleIoUtil(object):
             self.__applyOutputConstraints()
 
         if filePath.endswith(".tar.gz"):
-            return self.__writeTarGzFile(self.__outputFilePath, tmpPath=tmpPath)
+            return self.__writeTarGzFile(self.__outputFilePath, tmpPath=tmpPath, doubleQuotingFlag=doubleQuotingFlag)
         else:
-            return self.__write(self.__outputFilePath)
+            return self.__write(self.__outputFilePath, doubleQuotingFlag=doubleQuotingFlag)
 
-    def __write(self, filePath):
+    def __write(self, filePath, doubleQuotingFlag=False):
         """  Internal method to write the current container list to the specified outputfile -
 
              Returns True for success or False otherwise.
         """
         try:
-            self.__ioObj.writeFile(filePath, self.__currentContainerList)
+            self.__ioObj.writeFile(filePath, self.__currentContainerList, doubleQuotingFlag=doubleQuotingFlag)
         except Exception as e:
             if self.__verbose:
                 logger.exception("Failing with %s" % str(e))
@@ -448,7 +448,7 @@ class PdbxStyleIoUtil(object):
 
         return True
 
-    def __writeTarGzFile(self, tarGzFilePath, tmpPath="./tmpfiles"):
+    def __writeTarGzFile(self, tarGzFilePath, tmpPath="./tmpfiles", doubleQuotingFlag=False):
         """  Internal method to write the current container list to a split gzipped tar file.
 
              Returns True for success or False otherwise.
@@ -465,7 +465,7 @@ class PdbxStyleIoUtil(object):
             for container in self.__currentContainerList:
                 id = container.getName()
                 filePath = os.path.join(tmpPath, id + ".cif")
-                self.__ioObj.writeFile(filePath, [container])
+                self.__ioObj.writeFile(filePath, [container], doubleQuotingFlag=doubleQuotingFlag)
                 archive.add(filePath, arcname=id + ".cif", filter=tarinfoReset)
                 os.remove(filePath)
             archive.close()
